Package: ggguides
Title: Simplified Legend and Guide Alignment for 'ggplot2'
Version: 1.1.10
Authors@R: 
    person("Gilles", "Colling", email = "gilles.colling051@gmail.com", role = c("aut", "cre"))
Description: Provides one-liner functions for common legend and guide operations
    in 'ggplot2'. Simplifies legend positioning, styling, wrapping, and
    collection across multi-panel plots created with 'patchwork' or 'cowplot'.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: ggplot2 (>= 3.5.0), grid, gridExtra, gtable, rlang
Suggests: patchwork, testthat (>= 3.0.0), knitr, rmarkdown
VignetteBuilder: knitr
Config/testthat/edition: 3
URL: https://gillescolling.com/ggguides/,
        https://github.com/gcol33/ggguides
BugReports: https://github.com/gcol33/ggguides/issues
NeedsCompilation: no
Packaged: 2026-05-07 13:13:15 UTC; Gilles Colling
Author: Gilles Colling [aut, cre]
Maintainer: Gilles Colling <gilles.colling051@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-07 14:23:31 UTC
Built: R 4.6.0; ; 2026-05-07 16:33:51 UTC; unix
