# Generated by roxygen2: do not edit by hand

S3method(ggplotGrob,gg_autofit_legend)
S3method(ggplotGrob,gg_centered_title)
S3method(ggplotGrob,gg_per_legend_just)
S3method(ggplot_add,ggguides_guide_update)
S3method(ggplot_add,ggguides_legend_order)
S3method(ggplot_add,legend_style_centered)
S3method(plot,gg_autofit_legend)
S3method(plot,gg_centered_title)
S3method(plot,gg_per_legend_just)
S3method(print,gg_autofit_legend)
S3method(print,gg_centered_title)
S3method(print,gg_per_legend_just)
export(align_guides_h)
export(center_legend_title)
export(collect_axes)
export(collect_legends)
export(colorbar_style)
export(colourbar_style)
export(get_legend)
export(legend_auto_fit)
export(legend_bottom)
export(legend_hide)
export(legend_horizontal)
export(legend_inside)
export(legend_keys)
export(legend_left)
export(legend_merge)
export(legend_none)
export(legend_order)
export(legend_order_guides)
export(legend_reverse)
export(legend_right)
export(legend_select)
export(legend_split)
export(legend_style)
export(legend_top)
export(legend_vertical)
export(legend_wrap)
export(shared_legend)
import(ggplot2)
importFrom(ggplot2,ggplot_add)
importFrom(grid,unit)
importFrom(gtable,gtable_add_grob)
importFrom(gtable,gtable_filter)
importFrom(rlang,"%||%")
importFrom(rlang,check_installed)
importFrom(rlang,eval_tidy)
importFrom(rlang,is_installed)
