#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import ggplot2
#' @importFrom grid unit
#' @importFrom gtable gtable_filter gtable_add_grob
#' @importFrom rlang check_installed is_installed %||% eval_tidy
## usethis namespace: end
NULL
