% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/legend_position.R
\name{legend_none}
\alias{legend_none}
\title{Remove Legend from Plot}
\usage{
legend_none()
}
\value{
A ggplot2 theme object that can be added to a plot.
}
\description{
A one-liner to remove the legend from a plot. Cleaner alternative to
\code{theme(legend.position = "none")}.
}
\examples{
library(ggplot2)

# Remove legend
ggplot(mtcars, aes(mpg, wt, color = factor(cyl))) +
  geom_point() +
  legend_none()

}
\seealso{
\code{\link{legend_left}}, \code{\link{legend_right}}
}
