% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/legend_style.R
\name{print.gg_centered_title}
\alias{print.gg_centered_title}
\title{Print method for centered title plots}
\usage{
\method{print}{gg_centered_title}(x, ...)
}
\arguments{
\item{x}{A gg_centered_title object}

\item{...}{Additional arguments (ignored)}
}
\value{
Invisibly returns the input object. Called for the side effect of
rendering the plot with centered legend titles.
}
\description{
Print method for centered title plots
}
\keyword{internal}
