% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/legend_style.R
\name{ggplot_add.legend_style_centered}
\alias{ggplot_add.legend_style_centered}
\title{Add legend_style_centered to ggplot}
\usage{
\method{ggplot_add}{legend_style_centered}(object, plot, ...)
}
\arguments{
\item{object}{A legend_style_centered object}

\item{plot}{A ggplot object}

\item{...}{Additional arguments (ignored)}
}
\value{
A modified ggplot object with additional class \code{gg_centered_title}
or \code{gg_autofit_legend} (for 90-degree rotation), used to trigger
custom rendering behavior.
}
\description{
Add legend_style_centered to ggplot
}
\keyword{internal}
