% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ggguides-package.R
\docType{package}
\name{ggguides-package}
\alias{ggguides}
\alias{ggguides-package}
\title{ggguides: Simplified Legend and Guide Alignment for 'ggplot2'}
\description{
Provides one-liner functions for common legend and guide operations in 'ggplot2'. Simplifies legend positioning, styling, wrapping, and collection across multi-panel plots created with 'patchwork' or 'cowplot'.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://gillescolling.com/ggguides/}
  \item \url{https://github.com/gcol33/ggguides}
  \item Report bugs at \url{https://github.com/gcol33/ggguides/issues}
}

}
\author{
\strong{Maintainer}: Gilles Colling \email{gilles.colling051@gmail.com}

}
\keyword{internal}
