% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/legend_style.R
\name{plot.gg_autofit_legend}
\alias{plot.gg_autofit_legend}
\title{Plot method for auto-fit legend plots}
\usage{
\method{plot}{gg_autofit_legend}(x, ...)
}
\arguments{
\item{x}{A gg_autofit_legend object}

\item{...}{Additional arguments (ignored)}
}
\value{
Invisibly returns the input object. Called for the side effect of
rendering the plot with auto-fitted and centered legend.
}
\description{
Plot method for auto-fit legend plots
}
\keyword{internal}
